@@ -9,7 +9,7 @@
 #' 
 #' The analysis calculates effect sizes as standard deviates, z, and performs two-sample z-tests, using the pooled 
 #' standard error from the sampling distributions of the CR analyses. The method follows that of Adams and Collyer (2019) used 
-#' to compare patterns of integration via PLS across datasets
+#' to compare patterns of modularity across datasets.
 #'  
 #' To use this function, simply perform \code{\link{modularity.test}}, or \code{\link{phylo.modularity}} on as many samples or 
 #' alternative modular hypotheses as desired.  Any number of objects of class CR can be input. For the case of the latter, one may wish to
@@ -85,25 +85,27 @@ compare.CR <- function(...,CR.null = TRUE, two.tailed = TRUE){
    if(is.null(list.names)) list.names <- paste("CR", 1:n, sep = ".")
    names(dots) <- list.names
         
-   is.CR <- function(x) class(x) == "CR"
+   is.CR <- function(x) inherits(x, "CR")
    sdn <- function(x) sqrt(sum((x-mean(x))^2)/length(x))
    list.check <- sapply(1:length(dots), function(j) any(is.CR(dots[[j]])))
    if(any(list.check == FALSE)) stop("Not all objects are class CR")
    k <- length(list.check)
    if(is.null(list.names)) list.names <- as.list(substitute(list(...)))[-1L]
    k.combn <- combn(k,2)
-   list.sds <- sapply(1:k, function(j) sdn(scale(dots[[j]]$random.CR[-1])))
-   list.zs <- sapply(1:k, function(j) effect.size(dots[[j]]$random.CR, center=TRUE))  #NOTE: pull out RRPP::: once in geomorph
+   list.drs <- sapply(1:k, function(j) dots[[j]]$random.CR[1] - mean(dots[[j]]$random.CR[-1])) 
+   list.sds <- sapply(1:k, function(j) sdn(dots[[j]]$random.CR[-1]))
+   list.zs <- sapply(1:k, function(j) effect.size(dots[[j]]$random.CR, center=TRUE))  
    if (CR.null == TRUE){
       k <- k + 1
       k.combn <- combn(k,2)
+      list.drs <- c(0,list.drs) 
       list.sds <- c(0,list.sds)
       list.zs <- c(0,list.zs)
    }
-   #Changed this: no 'abs', and forced min as r1, then other as r2
    z12 <- sapply(1:ncol(k.combn), function(j){
-   a <- k.combn[1,j]; b <- k.combn[2,j]
-     r1 <- list.zs[a]; r2 <- list.zs[b]; sd1 <- list.sds[a]; sd2 <- list.sds[b]
+     a <- k.combn[1,j]; b <- k.combn[2,j]
+     r1 <- list.drs[a]; r2 <- list.drs[b] 
+     sd1 <- list.sds[a]; sd2 <- list.sds[b]
      (r1-r2)/sqrt(sd1^2+sd2^2)
    })
    z12.p <- sapply(1:length(z12), function(j) pnorm(abs(z12[[j]]), lower.tail = FALSE)* tails)  
@@ -125,7 +127,7 @@ compare.CR <- function(...,CR.null = TRUE, two.tailed = TRUE){
    comment <- c("NOTE: more negative effects represent stronger modular signal!")
    out <- list(comment=comment, sample.z = list.zs,
                sample.r.sd = list.sds,
-               pairwise.z = pairwise.z,
+               pairwise.z = abs(pairwise.z),
                pairwise.P = pairwise.P)
    class(out) <- "compare.CR"
    out
