@@ -86,18 +86,20 @@
      names(dots) <- list.names
      } else list.names <- names(dots)
    if(length(dots) < 2) stop("At least two objects of class pls are needed")
-   is.pls <- function(x) class(x) == "pls"
+   is.pls <- function(x) inherits(x, "pls")
    sdn <- function(x) sqrt(sum((x-mean(x))^2)/length(x))
    list.check <- sapply(1:length(dots), function(j) any(is.pls(dots[[j]])))
    if(any(list.check == FALSE)) stop("Not all objects are class pls")
    k <- length(list.check)
    if(is.null(list.names)) list.names <- as.list(substitute(list(...)))[-1L]
    k.combn <- combn(k,2)
-   list.sds <- sapply(1:k, function(j) sdn(scale(dots[[j]]$random.r[-1])))
+   list.drs <- sapply(1:k, function(j) dots[[j]]$random.r[1] - mean(dots[[j]]$random.r[-1])) 
+   list.sds <- sapply(1:k, function(j) sdn(dots[[j]]$random.r[-1]))
    list.zs <- sapply(1:k, function(j) effect.size(dots[[j]]$random.r, center=TRUE))
    z12 <- sapply(1:ncol(k.combn), function(j){
      a <- k.combn[1,j]; b <- k.combn[2,j]
-     r1 <- list.zs[a]; r2 <- list.zs[b]; sd1 <- list.sds[a]; sd2 <- list.sds[b]
+     r1 <- list.drs[a]; r2 <- list.drs[b] 
+     sd1 <- list.sds[a]; sd2 <- list.sds[b]
      (r1-r2)/sqrt(sd1^2+sd2^2)
    })
    z12.p <- sapply(1:length(z12), function(j) pnorm(abs(z12[[j]]), lower.tail = FALSE) * tails)
@@ -113,7 +115,7 @@
    
    out <- list(sample.z = list.zs,
                sample.r.sd = list.sds,
-               pairwise.z = pairwise.z,
+               pairwise.z = abs(pairwise.z),
                pairwise.P = pairwise.P)
    class(out) <- "compare.pls"
    out
